#!/bin/sh


MIN=$1
MAX=$2
AVG=$3
NRAY=$4
PERIOD=$5
S2=$6
M2=$7
FILE=$8
ID=$9
VEL=`echo ${AVG} | awk '{printf "%.4f",$1}' `

echo map.sh ${MIN} ${MAX} ${AVG}

#####
#    create a polar cps map
#####

gmt set PS_MEDIA ledger
gmt makecpt -Cpolar -T-11/11/1 > mypolar.cpt


#####
#   make a file of
#   Longitude Latitude Percentage
#####
cat > awkit << EOF
{
if(\$4 > -10.0){frac = 100.0*(\$3 - ${AVG})/${AVG} ; if (frac < -10.0)frac = -10.0; if (frac > 10.00) frac = 10.0; printf "%.4f %.4f %.1f 0.2 \n", \$1, \$2, -frac }
}
EOF
cat ${FILE} | awk -f awkit > pct

PROJ2="-R0/10.5/0/11/ -Jx3 -P -V"
#
PROJ="-R-128/-60/25/52 -JM-95.0/37/30c -P -V"
#
#
rm -f Rcspk.eps
# for GMT4
gmt set MEDIA ledger
#gmtset BASEMAP_TYPE FANCY OUTPUT_DEGREE_FORMAT -D PLOT_DEGREE_FORMAT ddd.xx MEASURE_UNIT cm  PAPER_MEDIA ledger+

gmt pscoast   ${PROJ}  -Bpx5 -Bpy2 -W -K -Na -Dh   -G240   >> Rcspk.eps
gmt psxy ./pct -Sc -Cmypolar.cpt  -: $PROJ -W0.01p -O  -K >> Rcspk.eps
gmt pscoast   ${PROJ}  -Bpx5 -Bpy2 -W -K -Na -Dh -O -K   >> Rcspk.eps

#####
#   plot a scale
#   first blank out an area
#   then split the scale
#####
gmt psxy  ${PROJ} -O -: -V -G255 -W1p -A -L -K >> Rcspk.eps << EOF
27.0 -127.2
27.0 -122.7
35.0 -122.7
35.0 -127.2
EOF

gmt pstext -: ${PROJ}  -O  -K -F+f+a+j >> Rcspk.eps << EOF
34.7 -126.0 12,Helvetica-Bold,black 0.0  TC  %
EOF
gmt psscale -O -K  -Cmypolar.cpt -B5::   -D0.5c/3.0c/3.0c/0.5c >> Rcspk.eps

#####
#	annotate the bottom of the figure
#####
gmt pstext ${PROJ2} -Y-3 -O -F+f+a+j   >> Rcspk.eps << EOF
1.0 0.5 12,Helvetica-Bold,black 0.0 BL ${ID}: Period=${PERIOD}s Vavg=${VEL}km/s ${NRAY} Rays used=${NRAY} Vmin=${MIN} Vmax=${MAX}
EOF
#pstext ${PROJ2} -Y-3 -O  -K >> Rcspk.eps << EOF
#1.0 0.5 12 0.0 5 5 ${PERIOD} S
#1.7 0.5 12 0.0 5 5 Vavg = ${VEL} km/s
#3.2 0.5 12 0.0 5 5 ${NRAY} Rays used
#4.2 0.5 12 0.0 5 5 Vmin = ${MIN}
#5.2 0.5 12 0.0 5 5 Vmax = ${MAX}
#EOF

